==> 4.0.4.tar.gz: student-legacy/filcnaplo_mobile_ui/lib/screens/settings/settings_screen.i18n.dart <==
import 'package:i18n_extension/i18n_extension.dart';

extension SettingsLocalization on String {
  static final _t = Translations.byLocale("hu_hu") +
      {
        "en_en": {
          "personal_details": "Personal Details",
          "open_dkt": "Open DKT",
          "edit_nickname": "Edit Nickname",
          "edit_profile_picture": "Edit Profile Picture",
          "remove_profile_picture": "Remove Profile Picture",
          "select_profile_picture": "to select a picture",
          "click_here": "Click here",
          "light": "Light",
          "dark": "Dark",
          "system": "System",
          "add_user": "Add User",
          "log_out": "Log Out",
          "update_available": "Update Available",
          "general": "General",
          "language": "Language",
          "startpage": "Startpage",
          "rounding": "Rounding",
          "appearance": "Appearance",
          "theme": "Theme",
          "color": "Color",
          "grade_colors": "Grade Colors",
          "notifications": "Notifications",
          "news": "News",
          "extras": "Extras",
          "about": "About",
          "supporters": "Supporters",
          "privacy": "Privacy Policy",
          "licenses": "Licenses",
          "vibrate": "Vibration",
          "voff": "Off",
          "vlight": "Light",
          "vmedium": "Medium",
          "vstrong": "Strong",
          "cancel": "Cancel",
          "done": "Done",
          "reset": "Reset",
          "open": "Open",
          "data_collected":
              "Data collected: Platform (eg. Android), App version (eg. 3.0.0), Unique Install Identifier",
          "Analytics": "Analytics",
          "Anonymous Usage Analytics": "Anonymous Usage Analytics",
          "graph_class_avg": "Class average on graph",
          "goodstudent": "Good student mode",
          "attention": "Attention!",
          "goodstudent_disclaimer":
              "reFilc can not be held liable for the usage of this feature.\n\n(if your mother beats you up because you showed her fake grades, you can only blame yourself for it)",
          "understand": "I understand",
          "secret": "Secret Settings",
          "bell_delay": "Bell Delay",
          "delay": "Delay",
          "hurry": "Hurry",
          "sync": "Synchronize",
          "sync_help": "Press the Synchronize button when the bell rings.",
          "surprise_grades": "Surprise Grades",
          "icon_pack": "Icon Pack",
          "change_username": "Set a nickname",
          "Accent Color": "Accent Color",
          "Background Color": "Background Color",
          "Highlight Color": "Highlight Color",
          "Adaptive Theme": "Adaptive Theme",
          "presentation": "Presentation mode",
          "uwufymode": "UwU-fied mode (hungarian)",
        },
        "hu_hu": {
          "personal_details": "Személyes információk",
          "open_dkt": "DKT megnyitása",
          "edit_nickname": "Becenév szerkesztése",
          "edit_profile_picture": "Profil-kép szerkesztése",
          "remove_profile_picture": "Profil-kép törlése",
          "select_profile_picture": "a kép kiválasztásához",
          "click_here": "Kattints ide",
          "light": "Világos",
          "dark": "Sötét",
          "system": "Rendszer",
          "add_user": "Felhasználó hozzáadása",
          "log_out": "Kijelentkezés",
          "update_available": "Frissítés elérhető",
          "general": "Általános",
          "language": "Nyelv",
          "startpage": "Kezdőlap",
          "rounding": "Kerekítés",
          "appearance": "Kinézet",
          "theme": "Téma",
          "color": "Színek",
          "grade_colors": "Jegyek színei",
          "notifications": "Értesítések",
          "news": "Hírek",
          "extras": "Extrák",
          "about": "Névjegy",
          "supporters": "Támogatók",
          "privacy": "Adatvédelmi irányelvek",
          "licenses": "Licencek",
          "vibrate": "Rezgés",
          "voff": "Kikapcsolás",
          "vlight": "Alacsony",
          "vmedium": "Közepes",
          "vstrong": "Erős",
          "cancel": "Mégsem",
          "done": "Kész",
          "reset": "Visszaállítás",
          "open": "Megnyitás",
          "data_collected":
              "Gyűjtött adat: Platform (pl. Android), App verzió (pl. 3.0.0), Egyedi telepítési azonosító",
          "Analytics": "Analitika",
          "Anonymous Usage Analytics": "Névtelen használati analitika",
          "graph_class_avg": "Osztályátlag a grafikonon",
          "goodstudent": "Jó tanuló mód",
          "attention": "Figyelem!",
          "goodstudent_disclaimer":
              "A reFilc minden felelősséget elhárít a funkció használatával kapcsolatban.\n\n(Értsd: ha az anyád megver, mert megtévesztő ábrákat mutattál neki, azért csakis magadadat hibáztathatod.)",
          "understand": "Értem",
          "secret": "Titkos Beállítások",
          "bell_delay": "Csengő eltolódása",
          "delay": "Késleltetés",
          "hurry": "Siettetés",
          "sync": "Szinkronizálás",
          "sync_help": "Csengetéskor nyomd meg a Szinkronizálás gombot.",
          "surprise_grades": "Meglepetés jegyek",
          "icon_pack": "Ikon séma",
          "change_username": "Becenév beállítása",
          "Accent Color": "Egyedi szín",
          "Background Color": "Háttér színe",
          "Highlight Color": "Panelek színe",
          "Adaptive Theme": "Adaptív téma",
          "presentation": "Bemutató mód",
          "uwufymode": "UwU mód (magyar)",
        },
        "de_de": {
          "personal_details": "Persönliche Angaben",
          "open_dkt": "Öffnen DKT",
          "edit_nickname": "Spitznamen bearbeiten",
          "edit_profile_picture": "Profilbild bearbeiten",
          "remove_profile_picture": "Profilbild entfernen",
          "select_profile_picture": "um ein Bild auszuwählen",
          "click_here": "Klick hier",
          "light": "Licht",
          "dark": "Dunkel",
          "system": "System",
          "add_user": "Benutzer hinzufügen",
          "log_out": "Abmelden",
          "update_available": "Update verfügbar",
          "general": "Allgemein",
          "language": "Sprache",
          "startpage": "Startseite",
          "rounding": "Rundung",
          "appearance": "Erscheinungsbild",
          "theme": "Thema",
          "color": "Farbe",
          "grade_colors": "Grad Farben",
          "notifications": "Benachrichtigungen",
          "news": "Nachrichten",
          "extras": "Extras",
          "about": "Informationen",
          "supporters": "Unterstützer",
          "privacy": "Datenschutzbestimmungen",
          "licenses": "Lizenzen",
          "vibrate": "Vibration",
          "voff": "Aus",
          "vlight": "Leicht",
          "vmedium": "Mittel",
          "vstrong": "Stark",
          "cancel": "Abbrechen",
          "done": "Fertig",
          "reset": "Zurücksetzen",
          "open": "Öffnen",
          "data_collected":
              "Erhobene Daten: Plattform (z.B. Android), App version (z.B. 3.0.0), Eindeutige Installationskennung",
          "Analytics": "Analytik",
          "Anonymous Usage Analytics": "Anonyme Nutzungsanalyse",
          "graph_class_avg": "Klassendurchschnitt in der Grafik",
          "goodstudent": "Guter Student Modus",
          "attention": "Achtung!",
          "goodstudent_disclaimer": "Same in English.",
          "understand": "Ich verstehe",
          "secret": "Geheime Einstellungen",
          "bell_delay": "Klingelverzögerung",
          "delay": "Verzögern",
          "hurry": "Eile",
          "sync": "Synchronisieren",
          "sync_help": "Drücken Sie die Sync-Taste, wenn die Glocke läutet.",
          "surprise_grades": "Überraschungsnoten",
          "icon_pack": "Icon-Pack",
          "change_username": "Einen Spitznamen festlegen",
          "Accent Color": "Accent Color",
          "Background Color": "Background Color",
          "Highlight Color": "Highlight Color",
          "Adaptive Theme": "Adaptive Theme",
          "presentation": "Präsentationsmodus",
          "uwufymode": "UwU-Modus (ungarisch)",
        },
      };

  String get i18n => localize(this, _t);
  String fill(List<Object> params) => localizeFill(this, params);
  String plural(int value) => localizePlural(value, this, _t);
  String version(Object modifier) => localizeVersion(modifier, this, _t);
}

==> 4.2.4-dev.tar.gz: student-legacy/filcnaplo_mobile_ui/lib/screens/settings/settings_screen.i18n.dart <==
import 'package:i18n_extension/i18n_extension.dart';

extension SettingsLocalization on String {
  static final _t = Translations.byLocale("hu_hu") +
      {
        "en_en": {
          "personal_details": "Personal Details",
          "open_dkt": "Open DKT",
          "edit_nickname": "Edit Nickname",
          "edit_profile_picture": "Edit Profile Picture",
          "remove_profile_picture": "Remove Profile Picture",
          "select_profile_picture": "to select a picture",
          "click_here": "Click here",
          "light": "Light",
          "dark": "Dark",
          "system": "System",
          "add_user": "Add User",
          "log_out": "Log Out",
          "update_available": "Update Available",
          "general": "General",
          "language": "Language",
          "startpage": "Startpage",
          "rounding": "Rounding",
          "appearance": "Appearance",
          "theme": "Theme",
          "color": "Color",
          "grade_colors": "Grade Colors",
          "live_activity_color": "Live Activity Color",
          "notifications": "Notifications",
          "popups": "Pop-up Alerts",
          "news": "News",
          "extras": "Extras",
          "about": "About",
          "supporters": "Supporters",
          "privacy": "Privacy Policy",
          "licenses": "Licenses",
          "vibrate": "Vibration",
          "voff": "Off",
          "vlight": "Light",
          "vmedium": "Medium",
          "vstrong": "Strong",
          "cancel": "Cancel",
          "done": "Done",
          "reset": "Reset",
          "open": "Open",
          "data_collected":
              "Data collected: Platform (eg. Android), App version (eg. 3.0.0), Unique Install Identifier",
          "Analytics": "Analytics",
          "Anonymous Usage Analytics": "Anonymous Usage Analytics",
          "graph_class_avg": "Class average on graph",
          "goodstudent": "Good student mode",
          "attention": "Attention!",
          "goodstudent_disclaimer":
              "reFilc can not be held liable for the usage of this feature.\n\n(if your mother beats you up because you showed her fake grades, you can only blame yourself for it)",
          "understand": "I understand",
          "secret": "Secret Settings",
          "bell_delay": "Bell Delay",
          "delay": "Delay",
          "hurry": "Hurry",
          "sync": "Synchronize",
          "sync_help": "Press the Synchronize button when the bell rings.",
          "surprise_grades": "Surprise Grades",
          "icon_pack": "Icon Pack",
          "change_username": "Set a nickname",
          "Accent Color": "Accent Color",
          "Background Color": "Background Color",
          "Highlight Color": "Highlight Color",
          "Adaptive Theme": "Adaptive Theme",
          "presentation": "Presentation mode",
          "uwufymode": "UwU-fied mode (hungarian)",
          "devmoretaps": "You are %s taps away from Developer Mode.",
          "devactivated": "Developer Mode successfully activated.",
          "devsettings": "Developer Settings",
          "devmode": "Developer Mode",
          "copy_jwt": "Copy JWT",
        },
        "hu_hu": {
          "personal_details": "Személyes információk",
          "open_dkt": "DKT megnyitása",
          "edit_nickname": "Becenév szerkesztése",
          "edit_profile_picture": "Profil-kép szerkesztése",
          "remove_profile_picture": "Profil-kép törlése",
          "select_profile_picture": "a kép kiválasztásához",
          "click_here": "Kattints ide",
          "light": "Világos",
          "dark": "Sötét",
          "system": "Rendszer",
          "add_user": "Felhasználó hozzáadása",
          "log_out": "Kijelentkezés",
          "update_available": "Frissítés elérhető",
          "general": "Általános",
          "language": "Nyelv",
          "startpage": "Kezdőlap",
          "rounding": "Kerekítés",
          "appearance": "Kinézet",
          "theme": "Téma",
          "color": "Színek",
          "grade_colors": "Jegyek színei",
          "live_activity_color": "Live Activity színe",
          "notifications": "Értesítések",
          "popups": "Pop-up értesítések",
          "news": "Hírek",
          "extras": "Extrák",
          "about": "Névjegy",
          "supporters": "Támogatók",
          "privacy": "Adatvédelmi irányelvek",
          "licenses": "Licencek",
          "vibrate": "Rezgés",
          "voff": "Kikapcsolás",
          "vlight": "Alacsony",
          "vmedium": "Közepes",
          "vstrong": "Erős",
          "cancel": "Mégsem",
          "done": "Kész",
          "reset": "Visszaállítás",
          "open": "Megnyitás",
          "data_collected":
              "Gyűjtött adat: Platform (pl. Android), App verzió (pl. 3.0.0), Egyedi telepítési azonosító",
          "Analytics": "Analitika",
          "Anonymous Usage Analytics": "Névtelen használati analitika",
          "graph_class_avg": "Osztályátlag a grafikonon",
          "goodstudent": "Jó tanuló mód",
          "attention": "Figyelem!",
          "goodstudent_disclaimer":
              "A reFilc minden felelősséget elhárít a funkció használatával kapcsolatban.\n\n(Értsd: ha az anyád megver, mert megtévesztő ábrákat mutattál neki, azért csakis magadadat hibáztathatod.)",
          "understand": "Értem",
          "secret": "Titkos Beállítások",
          "bell_delay": "Csengő eltolódása",
          "delay": "Késleltetés",
          "hurry": "Siettetés",
          "sync": "Szinkronizálás",
          "sync_help": "Csengetéskor nyomd meg a Szinkronizálás gombot.",
          "surprise_grades": "Meglepetés jegyek",
          "icon_pack": "Ikon séma",
          "change_username": "Becenév beállítása",
          "Accent Color": "Egyedi szín",
          "Background Color": "Háttér színe",
          "Highlight Color": "Panelek színe",
          "Adaptive Theme": "Adaptív téma",
          "presentation": "Bemutató mód",
          "uwufymode": "UwU mód (magyar)",
          "devmoretaps": "Még %s koppintásra vagy a Fejlesztői módtól.",
          "devactivated": "Fejlesztői mód sikeresen aktiválva.",
          "devsettings": "Fejlesztői Beállítások",
          "devmode": "Fejlesztői mód",
          "copy_jwt": "JWT másolása",
        },
        "de_de": {
          "personal_details": "Persönliche Angaben",
          "open_dkt": "Öffnen DKT",
          "edit_nickname": "Spitznamen bearbeiten",
          "edit_profile_picture": "Profilbild bearbeiten",
          "remove_profile_picture": "Profilbild entfernen",
          "select_profile_picture": "um ein Bild auszuwählen",
          "click_here": "Klick hier",
          "light": "Licht",
          "dark": "Dunkel",
          "system": "System",
          "add_user": "Benutzer hinzufügen",
          "log_out": "Abmelden",
          "update_available": "Update verfügbar",
          "general": "Allgemein",
          "language": "Sprache",
          "startpage": "Startseite",
          "rounding": "Rundung",
          "appearance": "Erscheinungsbild",
          "theme": "Thema",
          "color": "Farbe",
          "grade_colors": "Grad Farben",
          "live_activity_color": "Live Activity Farben",
          "notifications": "Mitteilung",
          "popups": "Popup-Nachrichten",
          "news": "Nachrichten",
          "extras": "Extras",
          "about": "Informationen",
          "supporters": "Unterstützer",
          "privacy": "Datenschutzbestimmungen",
          "licenses": "Lizenzen",
          "vibrate": "Vibration",
          "voff": "Aus",
          "vlight": "Leicht",
          "vmedium": "Mittel",
          "vstrong": "Stark",
          "cancel": "Abbrechen",
          "done": "Fertig",
          "reset": "Zurücksetzen",
          "open": "Öffnen",
          "data_collected":
              "Erhobene Daten: Plattform (z.B. Android), App version (z.B. 3.0.0), Eindeutige Installationskennung",
          "Analytics": "Analytik",
          "Anonymous Usage Analytics": "Anonyme Nutzungsanalyse",
          "graph_class_avg": "Klassendurchschnitt in der Grafik",
          "goodstudent": "Guter Student Modus",
          "attention": "Achtung!",
          "goodstudent_disclaimer": "Same in English.",
          "understand": "Ich verstehe",
          "secret": "Geheime Einstellungen",
          "bell_delay": "Klingelverzögerung",
          "delay": "Verzögern",
          "hurry": "Eile",
          "sync": "Synchronisieren",
          "sync_help": "Drücken Sie die Sync-Taste, wenn die Glocke läutet.",
          "surprise_grades": "Überraschungsnoten",
          "icon_pack": "Icon-Pack",
          "change_username": "Einen Spitznamen festlegen",
          "Accent Color": "Accent Color",
          "Background Color": "Background Color",
          "Highlight Color": "Highlight Color",
          "Adaptive Theme": "Adaptive Theme",
          "presentation": "Präsentationsmodus",
          "uwufymode": "UwU-Modus (ungarisch)",
          "devmoretaps": "Sie sind %s Taps vom Entwicklermodus entfernt.",
          "devactivated": "Entwicklermodus erfolgreich aktiviert.",
          "devsettings": "Entwickleroptionen",
          "devmode": "Entwicklermodus",
          "copy_jwt": "JWT kopieren",
        },
      };

  String get i18n => localize(this, _t);
  String fill(List<Object> params) => localizeFill(this, params);
  String plural(int value) => localizePlural(value, this, _t);
  String version(Object modifier) => localizeVersion(modifier, this, _t);
}
